@@ -134,14 +134,18 @@ def get_acquisition_dirs(input_dir, output_dir):
     search_dir = input_dir
     ac_dirs = search_directory(input_dir, output_dir, search_dir, list(), depth=3)
             
-    for dir in ac_dirs:
-        try:
-            get_metadata(dir)
-        except:
-            log("An error occurred attempting to read metadata for {}:".format(dir['path']), True)
-            log(traceback.format_exc(), True)
-            log("Adding {} to the No List".format(dir['path']), True)
-            no_list.append(dir['path'])
+    try:
+        for dir in ac_dirs:
+            try:
+                get_metadata(dir)
+            except:
+                log("An error occurred attempting to read metadata for {}:".format(dir['path']), True)
+                log(traceback.format_exc(), True)
+                log("Adding {} to the No List".format(dir['path']), True)
+                no_list.append(dir['path'])
+    except:
+        log(traceback.format_exc(), True)
+        messagebox.showwarning('Path Error', 'Cannot access: {}'.format(input_dir))
             
     unfinished_dirs = []    
     for dir in ac_dirs:
